pub enum AxisPoints {
Categorical(Vec<Data>),
Numeric {
positives: Vec<Data>,
negatives: Vec<Data>,
},
}Expand description
Representation of Scale points on an Axis.
Variants
Categorical(Vec<Data>)
Categorical points with no concept of negatives and positives.
Numeric
Numeric points with positive points and negative points split. Zero is considered a positive.