pub struct StackedBarChart {
pub bars: Vec<StackedBar>,
pub x_axis: Option<String>,
pub y_axis: Option<String>,
pub labels: HashSet<String>,
pub x_scale: Scale,
pub y_scale: Scale,
}Fields
bars: Vec<StackedBar>x_axis: Option<String>y_axis: Option<String>labels: HashSet<String>x_scale: Scaley_scale: ScaleImplementations
Sourceimpl StackedBarChart
impl StackedBarChart
pub fn x_axis(self, label: impl Into<String>) -> Self
pub fn y_axis(self, label: impl Into<String>) -> Self
Sourcepub fn has_true_negatives(&self) -> bool
pub fn has_true_negatives(&self) -> bool
Returns true any negative bar is not completely empty. For a Stacked bar chart, an empty point is defined as one which has a y data value of 0 or 0.0
Sourcepub fn has_true_positives(&self) -> bool
pub fn has_true_positives(&self) -> bool
Returns true any positive bar is not completely empty. For a Stacked bar chart, an empty point is defined as one which has a y data value of 0 or 0.0
pub fn remove_section(&mut self, bar: usize, section: impl Into<String>)
pub fn remove_section_all(&mut self, section: impl Into<String>)
pub fn add_section(&mut self, bar: usize, section: impl Into<String>)
pub fn add_section_all(&mut self, section: impl Into<String>)