pub enum LineLabelStrategy {
FromCell(usize),
Provided(Vec<String>),
None,
}Expand description
Determines how the labels of the line graph created from a sheet are handled
Variants
FromCell(usize)
Label is derived from a the cells of a column. The values are not used within the line graph
Provided(Vec<String>)
Labels for each line are provided. Excess labels are ignored. Lines with
no labels receive a LineLabelStrategy::None
None
No labels